@@ -679,20 +679,28 @@ res <- assertError(model <- SISe3(u0        = u0,
                                   epsilon   = 1))
 check_error(res, "'events' must be NULL or a data.frame.")
 
-## Check arguments to 'U' method
+## Check arguments to 'trajectory' method
 u0 <- data.frame(S = 100:105, I = 1:6, R = rep(0, 6))
 model <- SIR(u0 = u0, tspan = 1:10, beta = 0.16, gamma = 0.077)
 result <- run(model)
 res <- assertError(trajectory(result, compartments = c("A", "S")))
 check_error(res, "Non-existing compartment(s) in model: 'A'.")
-res <- assertError(trajectory(result, node = c("A", "S")))
-check_error(res, "'node' must be integer.")
-res <- assertError(trajectory(result, node = 3.4))
-check_error(res, "'node' must be integer.")
-res <- assertError(trajectory(result, node = 0))
-check_error(res, "'node' must be integer > 0.")
-res <- assertError(trajectory(result, node = 10))
-check_error(res, "'node' must be integer <= number of nodes.")
+res <- assertError(trajectory(result, index = c("A", "S")))
+check_error(
+    res,
+    "The node index must be an integer > 0 and <= number of nodes.")
+res <- assertError(trajectory(result, index = 3.4))
+check_error(
+    res,
+    "The node index must be an integer > 0 and <= number of nodes.")
+res <- assertError(trajectory(result, index = 0))
+check_error(
+    res,
+    "The node index must be an integer > 0 and <= number of nodes.")
+res <- assertError(trajectory(result, index = 10))
+check_error(
+    res,
+    "The node index must be an integer > 0 and <= number of nodes.")
 
 ## Check arguments to 'prevalence' method
 u0 <- data.frame(S = 100:105, I = 1:6, R = rep(0, 6))
@@ -702,14 +710,22 @@ res <- assertError(prevalence(result, A + S ~ S))
 check_error(res, "Non-existing compartment(s) in model: 'A'.")
 res <- assertError(prevalence(result, S ~ A + S))
 check_error(res, "Non-existing compartment(s) in model: 'A'.")
-res <- assertError(prevalence(result, I ~ S + I + R, node = c("A", "S")))
-check_error(res, "'node' must be integer.")
-res <- assertError(prevalence(result, I ~ S + I + R, node = 3.4))
-check_error(res, "'node' must be integer.")
-res <- assertError(prevalence(result, I ~ S + I + R, node = 0))
-check_error(res, "'node' must be integer > 0.")
-res <- assertError(prevalence(result, I ~ S + I + R, node = 10))
-check_error(res, "'node' must be integer <= number of nodes.")
+res <- assertError(prevalence(result, I ~ S + I + R, i = c("A", "S")))
+check_error(
+    res,
+    "The node index must be an integer > 0 and <= number of nodes.")
+res <- assertError(prevalence(result, I ~ S + I + R, i = 3.4))
+check_error(
+    res,
+    "The node index must be an integer > 0 and <= number of nodes.")
+res <- assertError(prevalence(result, I ~ S + I + R, i = 0))
+check_error(
+    res,
+    "The node index must be an integer > 0 and <= number of nodes.")
+res <- assertError(prevalence(result, I ~ S + I + R, i = 10))
+check_error(
+    res,
+    "The node index must be an integer > 0 and <= number of nodes.")
 
 ## Check 'gdata'
 model <- SISe(u0 = data.frame(S = 10, I = 0), tspan = 1:10, phi = 0,
